aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/staging/ath6kl/include/common
diff options
context:
space:
mode:
authorJoe Perches <joe@perches.com>2011-02-02 14:05:51 -0800
committerGreg Kroah-Hartman <gregkh@suse.de>2011-02-02 14:34:50 -0800
commite1ce2a3afe041c36ae397abf73f8059eb599e36e (patch)
treeb7e883d91a26f2081a73454f4f389f0ad89a86f6 /drivers/staging/ath6kl/include/common
parentstaging: ath6kl: Convert A_UINT16 to u16 (diff)
downloadlinux-dev-e1ce2a3afe041c36ae397abf73f8059eb599e36e.tar.xz
linux-dev-e1ce2a3afe041c36ae397abf73f8059eb599e36e.zip
staging: ath6kl: Convert A_UINT32 to u32
Signed-off-by: Joe Perches <joe@perches.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/ath6kl/include/common')
-rw-r--r--drivers/staging/ath6kl/include/common/AR6002/AR6002_regdump.h34
-rw-r--r--drivers/staging/ath6kl/include/common/AR6002/addrs.h6
-rw-r--r--drivers/staging/ath6kl/include/common/a_hci.h18
-rw-r--r--drivers/staging/ath6kl/include/common/bmi_msg.h86
-rw-r--r--drivers/staging/ath6kl/include/common/btcoexGpio.h4
-rw-r--r--drivers/staging/ath6kl/include/common/dbglog.h24
-rw-r--r--drivers/staging/ath6kl/include/common/dset_internal.h2
-rw-r--r--drivers/staging/ath6kl/include/common/dsetid.h12
-rw-r--r--drivers/staging/ath6kl/include/common/epping_test.h4
-rw-r--r--drivers/staging/ath6kl/include/common/htc.h2
-rw-r--r--drivers/staging/ath6kl/include/common/ini_dset.h2
-rw-r--r--drivers/staging/ath6kl/include/common/regdump.h8
-rw-r--r--drivers/staging/ath6kl/include/common/regulatory/reg_dbschema.h44
-rw-r--r--drivers/staging/ath6kl/include/common/targaddrs.h96
-rw-r--r--drivers/staging/ath6kl/include/common/testcmd.h48
-rw-r--r--drivers/staging/ath6kl/include/common/wmi.h462
-rw-r--r--drivers/staging/ath6kl/include/common/wmi_thin.h30
-rw-r--r--drivers/staging/ath6kl/include/common/wmix.h86
18 files changed, 484 insertions, 484 deletions
diff --git a/drivers/staging/ath6kl/include/common/AR6002/AR6002_regdump.h b/drivers/staging/ath6kl/include/common/AR6002/AR6002_regdump.h
index e3291cf4dbd4..4a9b275d68b8 100644
--- a/drivers/staging/ath6kl/include/common/AR6002/AR6002_regdump.h
+++ b/drivers/staging/ath6kl/include/common/AR6002/AR6002_regdump.h
@@ -29,28 +29,28 @@
* This must match the state saved by the target exception handler.
*/
struct XTensa_exception_frame_s {
- A_UINT32 xt_pc;
- A_UINT32 xt_ps;
- A_UINT32 xt_sar;
- A_UINT32 xt_vpri;
- A_UINT32 xt_a2;
- A_UINT32 xt_a3;
- A_UINT32 xt_a4;
- A_UINT32 xt_a5;
- A_UINT32 xt_exccause;
- A_UINT32 xt_lcount;
- A_UINT32 xt_lbeg;
- A_UINT32 xt_lend;
+ u32 xt_pc;
+ u32 xt_ps;
+ u32 xt_sar;
+ u32 xt_vpri;
+ u32 xt_a2;
+ u32 xt_a3;
+ u32 xt_a4;
+ u32 xt_a5;
+ u32 xt_exccause;
+ u32 xt_lcount;
+ u32 xt_lbeg;
+ u32 xt_lend;
- A_UINT32 epc1, epc2, epc3, epc4;
+ u32 epc1, epc2, epc3, epc4;
/* Extra info to simplify post-mortem stack walkback */
#define AR6002_REGDUMP_FRAMES 10
struct {
- A_UINT32 a0; /* pc */
- A_UINT32 a1; /* sp */
- A_UINT32 a2;
- A_UINT32 a3;
+ u32 a0; /* pc */
+ u32 a1; /* sp */
+ u32 a2;
+ u32 a3;
} wb[AR6002_REGDUMP_FRAMES];
};
typedef struct XTensa_exception_frame_s CPU_exception_frame_t;
diff --git a/drivers/staging/ath6kl/include/common/AR6002/addrs.h b/drivers/staging/ath6kl/include/common/AR6002/addrs.h
index eaaccf4cad7b..bbf8d42828c1 100644
--- a/drivers/staging/ath6kl/include/common/AR6002/addrs.h
+++ b/drivers/staging/ath6kl/include/common/AR6002/addrs.h
@@ -29,13 +29,13 @@
#if defined(AR6002_REV2)
#define AR6K_RAM_START 0x00500000
-#define TARG_RAM_OFFSET(vaddr) ((A_UINT32)(vaddr) & 0xfffff)
+#define TARG_RAM_OFFSET(vaddr) ((u32)(vaddr) & 0xfffff)
#define TARG_RAM_SZ (184*1024)
#define TARG_ROM_SZ (80*1024)
#endif
#if defined(AR6002_REV4) || defined(AR6003)
#define AR6K_RAM_START 0x00540000
-#define TARG_RAM_OFFSET(vaddr) (((A_UINT32)(vaddr) & 0xfffff) - 0x40000)
+#define TARG_RAM_OFFSET(vaddr) (((u32)(vaddr) & 0xfffff) - 0x40000)
#define TARG_RAM_SZ (256*1024)
#define TARG_ROM_SZ (256*1024)
#endif
@@ -49,7 +49,7 @@
#define TARG_RAM_ADDRS(byte_offset) AR6K_RAM_ADDR(byte_offset)
#define AR6K_ROM_START 0x004e0000
-#define TARG_ROM_OFFSET(vaddr) (((A_UINT32)(vaddr) & 0x1fffff) - 0xe0000)
+#define TARG_ROM_OFFSET(vaddr) (((u32)(vaddr) & 0x1fffff) - 0xe0000)
#define AR6K_ROM_ADDR(byte_offset) (AR6K_ROM_START+(byte_offset))
#define TARG_ROM_ADDRS(byte_offset) AR6K_ROM_ADDR(byte_offset)
diff --git a/drivers/staging/ath6kl/include/common/a_hci.h b/drivers/staging/ath6kl/include/common/a_hci.h
index 317ea57ba87f..3734662d614f 100644
--- a/drivers/staging/ath6kl/include/common/a_hci.h
+++ b/drivers/staging/ath6kl/include/common/a_hci.h
@@ -351,9 +351,9 @@ typedef struct flow_spec_t {
u8 id;
u8 service_type;
u16 max_sdu;
- A_UINT32 sdu_inter_arrival_time;
- A_UINT32 access_latency;
- A_UINT32 flush_timeout;
+ u32 sdu_inter_arrival_time;
+ u32 access_latency;
+ u32 flush_timeout;
} POSTPACK FLOW_SPEC;
@@ -559,15 +559,15 @@ typedef struct hci_event_amp_status_change_t{
typedef struct local_amp_info_resp_t {
u8 status;
u8 amp_status;
- A_UINT32 total_bw; /* kbps */
- A_UINT32 max_guranteed_bw; /* kbps */
- A_UINT32 min_latency;
- A_UINT32 max_pdu_size;
+ u32 total_bw; /* kbps */
+ u32 max_guranteed_bw; /* kbps */
+ u32 min_latency;
+ u32 max_pdu_size;
u8 amp_type;
u16 pal_capabilities;
u16 amp_assoc_len;
- A_UINT32 max_flush_timeout; /* in ms */
- A_UINT32 be_flush_timeout; /* in ms */
+ u32 max_flush_timeout; /* in ms */
+ u32 be_flush_timeout; /* in ms */
} POSTPACK LOCAL_AMP_INFO;
typedef struct amp_assoc_cmd_resp_t{
diff --git a/drivers/staging/ath6kl/include/common/btcoexGpio.h b/drivers/staging/ath6kl/include/common/btcoexGpio.h
index bc067f557eaa..9d5a239f1fba 100644
--- a/drivers/staging/ath6kl/include/common/btcoexGpio.h
+++ b/drivers/staging/ath6kl/include/common/btcoexGpio.h
@@ -71,8 +71,8 @@
-extern void btcoexDbgPulseWord(A_UINT32 gpioPinMask);
-extern void btcoexDbgPulse(A_UINT32 pin);
+extern void btcoexDbgPulseWord(u32 gpioPinMask);
+extern void btcoexDbgPulse(u32 pin);
#ifdef CONFIG_BTCOEX_ENABLE_GPIO_DEBUG
#define BTCOEX_DBG_PULSE_WORD(gpioPinMask) (btcoexDbgPulseWord(gpioPinMask))
diff --git a/drivers/staging/ath6kl/include/common/dbglog.h b/drivers/staging/ath6kl/include/common/dbglog.h
index 060a6b16c193..3a3d00da0b81 100644
--- a/drivers/staging/ath6kl/include/common/dbglog.h
+++ b/drivers/staging/ath6kl/include/common/dbglog.h
@@ -90,30 +90,30 @@ extern "C" {
PREPACK struct dbglog_buf_s {
struct dbglog_buf_s *next;
u8 *buffer;
- A_UINT32 bufsize;
- A_UINT32 length;
- A_UINT32 count;
- A_UINT32 free;
+ u32 bufsize;
+ u32 length;
+ u32 count;
+ u32 free;
} POSTPACK;
PREPACK struct dbglog_hdr_s {
struct dbglog_buf_s *dbuf;
- A_UINT32 dropped;
+ u32 dropped;
} POSTPACK;
PREPACK struct dbglog_config_s {
- A_UINT32 cfgvalid; /* Mask with valid config bits */
+ u32 cfgvalid; /* Mask with valid config bits */
union {
/* TODO: Take care of endianness */
struct {
- A_UINT32 mmask:16; /* Mask of modules with logging on */
- A_UINT32 rep:1; /* Reporting enabled or not */
- A_UINT32 tsr:3; /* Time stamp resolution. Def: 1 ms */
- A_UINT32 size:10; /* Report size in number of messages */
- A_UINT32 reserved:2;
+ u32 mmask:16; /* Mask of modules with logging on */
+ u32 rep:1; /* Reporting enabled or not */
+ u32 tsr:3; /* Time stamp resolution. Def: 1 ms */
+ u32 size:10; /* Report size in number of messages */
+ u32 reserved:2;
} dbglog_config;
- A_UINT32 value;
+ u32 value;
} u;
} POSTPACK;
diff --git a/drivers/staging/ath6kl/include/common/dset_internal.h b/drivers/staging/ath6kl/include/common/dset_internal.h
index 74914f9cb3c4..69475331eab7 100644
--- a/drivers/staging/ath6kl/include/common/dset_internal.h
+++ b/drivers/staging/ath6kl/include/common/dset_internal.h
@@ -48,7 +48,7 @@ typedef PREPACK struct dset_descriptor_s {
DataSet or pointer to original
dset_descriptor for patched
DataSet */
- A_UINT32 data_type; /* DSET_TYPE_*, above */
+ u32 data_type; /* DSET_TYPE_*, above */
void *AuxPtr; /* Additional data that might
needed for data_type. For
diff --git a/drivers/staging/ath6kl/include/common/dsetid.h b/drivers/staging/ath6kl/include/common/dsetid.h
index d08fdeb39ec3..090e30967925 100644
--- a/drivers/staging/ath6kl/include/common/dsetid.h
+++ b/drivers/staging/ath6kl/include/common/dsetid.h
@@ -81,8 +81,8 @@
* This allows for patches to be stored in flash.
*/
PREPACK struct patch_s {
- A_UINT32 *address;
- A_UINT32 data;
+ u32 *address;
+ u32 data;
} POSTPACK ;
/*
@@ -92,23 +92,23 @@ PREPACK struct patch_s {
* patch code. The "data" in a PATCH_SKIP tells how many
* bytes of length "patch_s" to skip.
*/
-#define PATCH_SKIP ((A_UINT32 *)0x00000000)
+#define PATCH_SKIP ((u32 *)0x00000000)
/*
* Execute code at the address specified by "data".
* The address of the patch structure is passed as
* the one parameter.
*/
-#define PATCH_CODE_ABS ((A_UINT32 *)0x00000001)
+#define PATCH_CODE_ABS ((u32 *)0x00000001)
/*
* Same as PATCH_CODE_ABS, but treat "data" as an
* offset from the start of the patch word.
*/
-#define PATCH_CODE_REL ((A_UINT32 *)0x00000002)
+#define PATCH_CODE_REL ((u32 *)0x00000002)
/* Mark the end of this patch DataSet. */
-#define PATCH_END ((A_UINT32 *)0xffffffff)
+#define PATCH_END ((u32 *)0xffffffff)
/*
* A DataSet which contains a Binary Patch to some other DataSet
diff --git a/drivers/staging/ath6kl/include/common/epping_test.h b/drivers/staging/ath6kl/include/common/epping_test.h
index 45f82dd79236..2cd43c46c144 100644
--- a/drivers/staging/ath6kl/include/common/epping_test.h
+++ b/drivers/staging/ath6kl/include/common/epping_test.h
@@ -54,8 +54,8 @@ typedef PREPACK struct {
u8 _pad[2]; /* padding for alignment */
u8 TimeStamp[8]; /* timestamp of packet (host or target) */
- A_UINT32 HostContext_h; /* 4 byte host context, target echos this back */
- A_UINT32 SeqNo; /* sequence number (set by host or target) */
+ u32 HostContext_h; /* 4 byte host context, target echos this back */
+ u32 SeqNo; /* sequence number (set by host or target) */
u16 Cmd_h; /* ping command (filled by host) */
u16 CmdFlags_h; /* optional flags */
u8 CmdBuffer_h[8]; /* buffer for command (host -> target) */
diff --git a/drivers/staging/ath6kl/include/common/htc.h b/drivers/staging/ath6kl/include/common/htc.h
index 6c85bebd994d..bed8e26abc3d 100644
--- a/drivers/staging/ath6kl/include/common/htc.h
+++ b/drivers/staging/ath6kl/include/common/htc.h
@@ -181,7 +181,7 @@ typedef PREPACK struct {
/* extended setup completion message */
typedef PREPACK struct {
u16 MessageID;
- A_UINT32 SetupFlags;
+ u32 SetupFlags;
u8 MaxMsgsPerBundledRecv;
u8 Rsvd[3];
} POSTPACK HTC_SETUP_COMPLETE_EX_MSG;
diff --git a/drivers/staging/ath6kl/include/common/ini_dset.h b/drivers/staging/ath6kl/include/common/ini_dset.h
index d6f2301f5713..8bfc75940c8f 100644
--- a/drivers/staging/ath6kl/include/common/ini_dset.h
+++ b/drivers/staging/ath6kl/include/common/ini_dset.h
@@ -76,7 +76,7 @@ typedef enum {
typedef PREPACK struct {
u16 freqIndex; // 1 - A mode 2 - B or G mode 0 - common
u16 offset;
- A_UINT32 newValue;
+ u32 newValue;
} POSTPACK INI_DSET_REG_OVERRIDE;
#endif
diff --git a/drivers/staging/ath6kl/include/common/regdump.h b/drivers/staging/ath6kl/include/common/regdump.h
index ff79b4846e69..aa64821617e8 100644
--- a/drivers/staging/ath6kl/include/common/regdump.h
+++ b/drivers/staging/ath6kl/include/common/regdump.h
@@ -42,10 +42,10 @@
* the diagnostic window.
*/
PREPACK struct register_dump_s {
- A_UINT32 target_id; /* Target ID */
- A_UINT32 assline; /* Line number (if assertion failure) */
- A_UINT32 pc; /* Program Counter at time of exception */
- A_UINT32 badvaddr; /* Virtual address causing exception */
+ u32 target_id; /* Target ID */
+ u32 assline; /* Line number (if assertion failure) */
+ u32 pc; /* Program Counter at time of exception */
+ u32 badvaddr; /* Virtual address causing exception */
CPU_exception_frame_t exc_frame; /* CPU-specific exception info */
/* Could copy top of stack here, too.... */
diff --git a/drivers/staging/ath6kl/include/common/regulatory/reg_dbschema.h b/drivers/staging/ath6kl/include/common/regulatory/reg_dbschema.h
index 36e266fe02dd..93d7c0b64fd6 100644
--- a/drivers/staging/ath6kl/include/common/regulatory/reg_dbschema.h
+++ b/drivers/staging/ath6kl/include/common/regulatory/reg_dbschema.h
@@ -145,22 +145,22 @@ typedef PREPACK struct dbMasterTable_t { /* Hold ptrs to Table data structure
#define BMZERO {0,0} /* BMLEN zeros */
#define BM(_fa, _fb, _fc, _fd, _fe, _ff, _fg, _fh) \
- {((((_fa >= 0) && (_fa < 32)) ? (((A_UINT32) 1) << _fa) : 0) | \
- (((_fb >= 0) && (_fb < 32)) ? (((A_UINT32) 1) << _fb) : 0) | \
- (((_fc >= 0) && (_fc < 32)) ? (((A_UINT32) 1) << _fc) : 0) | \
- (((_fd >= 0) && (_fd < 32)) ? (((A_UINT32) 1) << _fd) : 0) | \
- (((_fe >= 0) && (_fe < 32)) ? (((A_UINT32) 1) << _fe) : 0) | \
- (((_ff >= 0) && (_ff < 32)) ? (((A_UINT32) 1) << _ff) : 0) | \
- (((_fg >= 0) && (_fg < 32)) ? (((A_UINT32) 1) << _fg) : 0) | \
- (((_fh >= 0) && (_fh < 32)) ? (((A_UINT32) 1) << _fh) : 0)), \
- ((((_fa > 31) && (_fa < 64)) ? (((A_UINT32) 1) << (_fa - 32)) : 0) | \
- (((_fb > 31) && (_fb < 64)) ? (((A_UINT32) 1) << (_fb - 32)) : 0) | \
- (((_fc > 31) && (_fc < 64)) ? (((A_UINT32) 1) << (_fc - 32)) : 0) | \
- (((_fd > 31) && (_fd < 64)) ? (((A_UINT32) 1) << (_fd - 32)) : 0) | \
- (((_fe > 31) && (_fe < 64)) ? (((A_UINT32) 1) << (_fe - 32)) : 0) | \
- (((_ff > 31) && (_ff < 64)) ? (((A_UINT32) 1) << (_ff - 32)) : 0) | \
- (((_fg > 31) && (_fg < 64)) ? (((A_UINT32) 1) << (_fg - 32)) : 0) | \
- (((_fh > 31) && (_fh < 64)) ? (((A_UINT32) 1) << (_fh - 32)) : 0))}
+ {((((_fa >= 0) && (_fa < 32)) ? (((u32) 1) << _fa) : 0) | \
+ (((_fb >= 0) && (_fb < 32)) ? (((u32) 1) << _fb) : 0) | \
+ (((_fc >= 0) && (_fc < 32)) ? (((u32) 1) << _fc) : 0) | \
+ (((_fd >= 0) && (_fd < 32)) ? (((u32) 1) << _fd) : 0) | \
+ (((_fe >= 0) && (_fe < 32)) ? (((u32) 1) << _fe) : 0) | \
+ (((_ff >= 0) && (_ff < 32)) ? (((u32) 1) << _ff) : 0) | \
+ (((_fg >= 0) && (_fg < 32)) ? (((u32) 1) << _fg) : 0) | \
+ (((_fh >= 0) && (_fh < 32)) ? (((u32) 1) << _fh) : 0)), \
+ ((((_fa > 31) && (_fa < 64)) ? (((u32) 1) << (_fa - 32)) : 0) | \
+ (((_fb > 31) && (_fb < 64)) ? (((u32) 1) << (_fb - 32)) : 0) | \
+ (((_fc > 31) && (_fc < 64)) ? (((u32) 1) << (_fc - 32)) : 0) | \
+ (((_fd > 31) && (_fd < 64)) ? (((u32) 1) << (_fd - 32)) : 0) | \
+ (((_fe > 31) && (_fe < 64)) ? (((u32) 1) << (_fe - 32)) : 0) | \
+ (((_ff > 31) && (_ff < 64)) ? (((u32) 1) << (_ff - 32)) : 0) | \
+ (((_fg > 31) && (_fg < 64)) ? (((u32) 1) << (_fg - 32)) : 0) | \
+ (((_fh > 31) && (_fh < 64)) ? (((u32) 1) << (_fh - 32)) : 0))}
/*
@@ -174,7 +174,7 @@ typedef PREPACK struct reg_dmn_pair_mapping {
u16 regDmn2GHz; /* 2GHz reg domain */
u8 flags5GHz; /* Requirements flags (AdHoc disallow etc) */
u8 flags2GHz; /* Requirements flags (AdHoc disallow etc) */
- A_UINT32 pscanMask; /* Passive Scan flags which can override unitary domain passive scan
+ u32 pscanMask; /* Passive Scan flags which can override unitary domain passive scan
flags. This value is used as a mask on the unitary flags*/
} POSTPACK REG_DMN_PAIR_MAPPING;
@@ -215,8 +215,8 @@ typedef PREPACK struct RegDmnFreqBand {
u8 channelSep; /* Channel separation within the band */
u8 useDfs; /* Use DFS in the RegDomain if corresponding bit is set */
u8 mode; /* Mode of operation */
- A_UINT32 usePassScan; /* Use Passive Scan in the RegDomain if corresponding bit is set */
- A_UINT32 ht40ChanMask; /* lower 16 bits: indicate which frequencies in the block is HT40 capable
+ u32 usePassScan; /* Use Passive Scan in the RegDomain if corresponding bit is set */
+ u32 ht40ChanMask; /* lower 16 bits: indicate which frequencies in the block is HT40 capable
upper 16 bits: what rate (half/quarter) the channel is */
} POSTPACK REG_DMN_FREQ_BAND;
@@ -229,9 +229,9 @@ typedef PREPACK struct regDomain {
u8 dfsMask; /* DFS bitmask for 5Ghz tables */
u8 flags; /* Requirement flags (AdHoc disallow etc) */
u16 reserved; /* for alignment */
- A_UINT32 pscan; /* Bitmask for passive scan */
- A_UINT32 chan11a[BMLEN]; /* 64 bit bitmask for channel/band selection */
- A_UINT32 chan11bg[BMLEN];/* 64 bit bitmask for channel/band selection */
+ u32 pscan; /* Bitmask for passive scan */
+ u32 chan11a[BMLEN]; /* 64 bit bitmask for channel/band selection */
+ u32 chan11bg[BMLEN];/* 64 bit bitmask for channel/band selection */
} POSTPACK REG_DOMAIN;
#endif /* __REG_DBSCHEMA_H__ */
diff --git a/drivers/staging/ath6kl/include/common/testcmd.h b/drivers/staging/ath6kl/include/common/testcmd.h
index 4138c1d13d15..49861e2058f0 100644
--- a/drivers/staging/ath6kl/include/common/testcmd.h
+++ b/drivers/staging/ath6kl/include/common/testcmd.h
@@ -82,20 +82,20 @@ typedef enum {
} TCMD_WLAN_MODE;
typedef PREPACK struct {
- A_UINT32 testCmdId;
- A_UINT32 mode;
- A_UINT32 freq;
- A_UINT32 dataRate;
+ u32 testCmdId;
+ u32 mode;
+ u32 freq;
+ u32 dataRate;
A_INT32 txPwr;
- A_UINT32 antenna;
- A_UINT32 enANI;
- A_UINT32 scramblerOff;
- A_UINT32 aifsn;
+ u32 antenna;
+ u32 enANI;
+ u32 scramblerOff;
+ u32 aifsn;
u16 pktSz;
u16 txPattern;
- A_UINT32 shortGuard;
- A_UINT32 numPackets;
- A_UINT32 wlanMode;
+ u32 shortGuard;
+ u32 numPackets;
+ u32 wlanMode;
} POSTPACK TCMD_CONT_TX;
#define TCMD_TXPATTERN_ZERONE 0x1
@@ -124,20 +124,20 @@ typedef enum {
} TCMD_CONT_RX_ACT;
typedef PREPACK struct {
- A_UINT32 testCmdId;
- A_UINT32 act;
- A_UINT32 enANI;
+ u32 testCmdId;
+ u32 act;
+ u32 enANI;
PREPACK union {
struct PREPACK TCMD_CONT_RX_PARA {
- A_UINT32 freq;
- A_UINT32 antenna;
- A_UINT32 wlanMode;
+ u32 freq;
+ u32 antenna;
+ u32 wlanMode;
} POSTPACK para;
struct PREPACK TCMD_CONT_RX_REPORT {
- A_UINT32 totalPkt;
+ u32 totalPkt;
A_INT32 rssiInDBm;
- A_UINT32 crcErrPkt;
- A_UINT32 secErrPkt;
+ u32 crcErrPkt;
+ u32 secErrPkt;
u16 rateCnt[TCMD_MAX_RATES];
u16 rateCntShortGuard[TCMD_MAX_RATES];
} POSTPACK report;
@@ -145,8 +145,8 @@ typedef PREPACK struct {
A_UCHAR addr[ATH_MAC_LEN];
} POSTPACK mac;
struct PREPACK TCMD_CONT_RX_ANT_SWITCH_TABLE {
- A_UINT32 antswitch1;
- A_UINT32 antswitch2;
+ u32 antswitch1;
+ u32 antswitch2;
}POSTPACK antswitchtable;
} POSTPACK u;
} POSTPACK TCMD_CONT_RX;
@@ -162,8 +162,8 @@ typedef enum {
} TCMD_PM_MODE;
typedef PREPACK struct {
- A_UINT32 testCmdId;
- A_UINT32 mode;
+ u32 testCmdId;
+ u32 mode;
} POSTPACK TCMD_PM;
typedef enum {
diff --git a/drivers/staging/ath6kl/include/common/wmi.h b/drivers/staging/ath6kl/include/common/wmi.h
index d4f8d404b6ee..1f90975aac66 100644
--- a/drivers/staging/ath6kl/include/common/wmi.h
+++ b/drivers/staging/ath6kl/include/common/wmi.h
@@ -70,7 +70,7 @@ extern "C" {
#endif
PREPACK struct host_app_area_s {
- A_UINT32 wmi_protocol_ver;
+ u32 wmi_protocol_ver;
} POSTPACK;
/*
@@ -533,7 +533,7 @@ typedef PREPACK struct {
A_UCHAR ssid[WMI_MAX_SSID_LEN];
u16 channel;
u8 bssid[ATH_MAC_LEN];
- A_UINT32 ctrl_flags;
+ u32 ctrl_flags;
} POSTPACK WMI_CONNECT_CMD;
/*
@@ -637,8 +637,8 @@ typedef enum {
typedef PREPACK struct {
u32 forceFgScan;
u32 isLegacy; /* For Legacy Cisco AP compatibility */
- A_UINT32 homeDwellTime; /* Maximum duration in the home channel(milliseconds) */
- A_UINT32 forceScanInterval; /* Time interval between scans (milliseconds)*/
+ u32 homeDwellTime; /* Maximum duration in the home channel(milliseconds) */
+ u32 forceScanInterval; /* Time interval between scans (milliseconds)*/
u8 scanType; /* WMI_SCAN_TYPE */
u8 numChannels; /* how many channels follow */
u16 channelList[1]; /* channels in Mhz */
@@ -685,7 +685,7 @@ typedef PREPACK struct {
u8 scanCtrlFlags;
u16 minact_chdwell_time; /* msec */
u16 maxact_scan_per_ssid; /* max active scans per ssid */
- A_UINT32 max_dfsch_act_time; /* msecs */
+ u32 max_dfsch_act_time; /* msecs */
} POSTPACK WMI_SCAN_PARAMS_CMD;
/*
@@ -706,7 +706,7 @@ typedef PREPACK struct {
u8 bssFilter; /* see WMI_BSS_FILTER */
u8 reserved1; /* For alignment */
u16 reserved2; /* For alignment */
- A_UINT32 ieMask;
+ u32 ieMask;
} POSTPACK WMI_BSS_FILTER_CMD;
/*
@@ -780,8 +780,8 @@ typedef PREPACK struct {
} POSTPACK WMI_SET_PARAMS_REPLY;
typedef PREPACK struct {
- A_UINT32 opcode;
- A_UINT32 length;
+ u32 opcode;
+ u32 length;
char buffer[1]; /* WMI_SET_PARAMS */
} POSTPACK WMI_SET_PARAMS_CMD;
@@ -849,8 +849,8 @@ typedef enum {
} WMI_AP_PS_TYPE;
typedef PREPACK struct {
- A_UINT32 idle_time; /* in msec */
- A_UINT32 ps_period; /* in usec */
+ u32 idle_time; /* in msec */
+ u32 ps_period; /* in usec */
u8 sleep_period; /* in ps periods */
u8 psType;
} POSTPACK WMI_AP_PS_CMD;
@@ -868,8 +868,8 @@ typedef enum {
typedef PREPACK struct {
u16 psPollTimeout; /* msec */
u16 triggerTimeout; /* msec */
- A_UINT32 apsdTimPolicy; /* TIM behavior with ques APSD enabled. Default is IGNORE_TIM_ALL_QUEUES_APSD */
- A_UINT32 simulatedAPSDTimPolicy; /* TIM behavior with simulated APSD enabled. Default is PROCESS_TIM_SIMULATED_APSD */
+ u32 apsdTimPolicy; /* TIM behavior with ques APSD enabled. Default is IGNORE_TIM_ALL_QUEUES_APSD */
+ u32 simulatedAPSDTimPolicy; /* TIM behavior with simulated APSD enabled. Default is PROCESS_TIM_SIMULATED_APSD */
} POSTPACK WMI_POWERSAVE_TIMERS_POLICY_CMD;
/*
@@ -928,19 +928,19 @@ typedef PREPACK struct {
* WMI_CREATE_PSTREAM_CMDID
*/
typedef PREPACK struct {
- A_UINT32 minServiceInt; /* in milli-sec */
- A_UINT32 maxServiceInt; /* in milli-sec */
- A_UINT32 inactivityInt; /* in milli-sec */
- A_UINT32 suspensionInt; /* in milli-sec */
- A_UINT32 serviceStartTime;
- A_UINT32 minDataRate; /* in bps */
- A_UINT32 meanDataRate; /* in bps */
- A_UINT32 peakDataRate; /* in bps */
- A_UINT32 maxBurstSize;
- A_UINT32 delayBound;
- A_UINT32 minPhyRate; /* in bps */
- A_UINT32 sba;
- A_UINT32 mediumTime;
+ u32 minServiceInt; /* in milli-sec */
+ u32 maxServiceInt; /* in milli-sec */
+ u32 inactivityInt; /* in milli-sec */
+ u32 suspensionInt; /* in milli-sec */
+ u32 serviceStartTime;
+ u32 minDataRate; /* in bps */
+ u32 meanDataRate; /* in bps */
+ u32 peakDataRate; /* in bps */
+ u32 maxBurstSize;
+ u32 delayBound;
+ u32 minPhyRate; /* in bps */
+ u32 sba;
+ u32 mediumTime;
u16 nominalMSDU; /* in octects */
u16 maxMSDU; /* in octects */
u8 trafficClass;
@@ -995,7 +995,7 @@ typedef PREPACK struct {
*/
typedef PREPACK struct WMI_RSSI_THRESHOLD_PARAMS{
- A_UINT32 pollTime; /* Polling time as a factor of LI */
+ u32 pollTime; /* Polling time as a factor of LI */
A_INT16 thresholdAbove1_Val; /* lowest of upper */
A_INT16 thresholdAbove2_Val;
A_INT16 thresholdAbove3_Val;
@@ -1018,7 +1018,7 @@ typedef PREPACK struct WMI_RSSI_THRESHOLD_PARAMS{
*/
typedef PREPACK struct WMI_SNR_THRESHOLD_PARAMS{
- A_UINT32 pollTime; /* Polling time as a factor of LI */
+ u32 pollTime; /* Polling time as a factor of LI */
u8 weight; /* "alpha" */
u8 thresholdAbove1_Val; /* lowest of uppper*/
u8 thresholdAbove2_Val;
@@ -1073,7 +1073,7 @@ typedef PREPACK struct {
* via event, unless the bitmask is set again.
*/
typedef PREPACK struct {
- A_UINT32 bitmask;
+ u32 bitmask;
} POSTPACK WMI_TARGET_ERROR_REPORT_BITMASK;
/*
@@ -1252,7 +1252,7 @@ typedef PREPACK struct {
} POSTPACK WMI_SET_MAX_OFFHOME_DURATION_CMD;
typedef PREPACK struct {
- A_UINT32 frequency;
+ u32 frequency;
u8 threshold;
} POSTPACK WMI_SET_HB_CHALLENGE_RESP_PARAMS_CMD;
/*---------------------- BTCOEX RELATED -------------------------------------*/
@@ -1329,13 +1329,13 @@ typedef enum {
#define BT_SCO_SET_MAX_LOW_RATE_CNT(flags,val) (flags) |= (((val) & 0xFF) << 16)
typedef PREPACK struct {
- A_UINT32 numScoCyclesForceTrigger; /* Number SCO cycles after which
+ u32 numScoCyclesForceTrigger; /* Number SCO cycles after which
force a pspoll. default = 10 */
- A_UINT32 dataResponseTimeout; /* Timeout Waiting for Downlink pkt
+ u32 dataResponseTimeout; /* Timeout Waiting for Downlink pkt
in response for ps-poll,
default = 10 msecs */
- A_UINT32 stompScoRules;
- A_UINT32 scoOptFlags; /* SCO Options Flags :
+ u32 stompScoRules;
+ u32 scoOptFlags; /* SCO Options Flags :
bits: meaning:
0 Allow Close Range Optimization
1 Force awake during close range
@@ -1377,13 +1377,13 @@ typedef PREPACK struct {
#define BT_A2DP_SET_MAX_LOW_RATE_CNT(flags,val) (flags) |= (((val) & 0xFF) << 16)
typedef PREPACK struct {
- A_UINT32 a2dpWlanUsageLimit; /* MAX time firmware uses the medium for
+ u32 a2dpWlanUsageLimit; /* MAX time firmware uses the medium for
wlan, after it identifies the idle time
default (30 msecs) */
- A_UINT32 a2dpBurstCntMin; /* Minimum number of bluetooth data frames
+ u32 a2dpBurstCntMin; /* Minimum number of bluetooth data frames
to replenish Wlan Usage limit (default 3) */
- A_UINT32 a2dpDataRespTimeout;
- A_UINT32 a2dpOptFlags; /* A2DP Option flags:
+ u32 a2dpDataRespTimeout;
+ u32 a2dpOptFlags; /* A2DP Option flags:
bits: meaning:
0 Allow Close Range Optimization
1 Force awake during close range
@@ -1402,14 +1402,14 @@ typedef PREPACK struct {
/* During BT ftp/ BT OPP or any another data based acl profile on bluetooth
(non a2dp).*/
typedef PREPACK struct {
- A_UINT32 aclWlanMediumUsageTime; /* Wlan usage time during Acl (non-a2dp)
+ u32 aclWlanMediumUsageTime; /* Wlan usage time during Acl (non-a2dp)
coexistence (default 30 msecs) */
- A_UINT32 aclBtMediumUsageTime; /* Bt usage time during acl coexistence
+ u32 aclBtMediumUsageTime; /* Bt usage time during acl coexistence
(default 30 msecs)*/
- A_UINT32 aclDataRespTimeout;
- A_UINT32 aclDetectTimeout; /* ACL coexistence enabled if we get
+ u32 aclDataRespTimeout;
+ u32 aclDetectTimeout; /* ACL coexistence enabled if we get
10 Pkts in X msec(default 100 msecs) */
- A_UINT32 aclmaxPktCnt; /* No of ACL pkts to receive before
+ u32 aclmaxPktCnt; /* No of ACL pkts to receive before
enabling ACL coex */
}POSTPACK BT_PARAMS_ACLCOEX;
@@ -1478,20 +1478,20 @@ typedef PREPACK struct {
* During this the station will be power-save mode.
*/
typedef PREPACK struct {
- A_UINT32 btInquiryDataFetchFrequency;/* The frequency of querying the AP for data
+ u32 btInquiryDataFetchFrequency;/* The frequency of querying the AP for data
(via pspoll) is configured by this parameter.
"default = 10 ms" */
- A_UINT32 protectBmissDurPostBtInquiry;/* The firmware will continue to be in inquiry state
+ u32 protectBmissDurPostBtInquiry;/* The firmware will continue to be in inquiry state
for configured duration, after inquiry completion
. This is to ensure other bluetooth transactions
(RDP, SDP profiles, link key exchange ...etc)
goes through smoothly without wifi stomping.
default = 10 secs*/
- A_UINT32 maxpageStomp; /*Applicable only for STE-BT interface. Currently not
+ u32 maxpageStomp; /*Applicable only for STE-BT interface. Currently not
used */
- A_UINT32 btInquiryPageFlag; /* Not used */
+ u32 btInquiryPageFlag; /* Not used */
}POSTPACK WMI_SET_BTCOEX_BTINQUIRY_PAGE_CONFIG_CMD;
/*---------------------WMI_SET_BTCOEX_SCO_CONFIG_CMDID ---------------*/
@@ -1509,14 +1509,14 @@ typedef PREPACK struct {
#define WMI_SCO_CONFIG_FLAG_IS_BT_MASTER (1 << 2)
#define WMI_SCO_CONFIG_FLAG_FW_DETECT_OF_PER (1 << 3)
typedef PREPACK struct {
- A_UINT32 scoSlots; /* Number of SCO Tx/Rx slots.
+ u32 scoSlots; /* Number of SCO Tx/Rx slots.
HVx, EV3, 2EV3 = 2 */
- A_UINT32 scoIdleSlots; /* Number of Bluetooth idle slots between
+ u32 scoIdleSlots; /* Number of Bluetooth idle slots between
consecutive SCO Tx/Rx slots
HVx, EV3 = 4
2EV3 = 10
*/
- A_UINT32 scoFlags; /* SCO Options Flags :
+ u32 scoFlags; /* SCO Options Flags :
bits: meaning:
0 Allow Close Range Optimization
1 Is EDR capable or Not
@@ -1524,21 +1524,21 @@ typedef PREPACK struct {
3 Firmware determines the periodicity of SCO.
*/
- A_UINT32 linkId; /* applicable to STE-BT - not used */
+ u32 linkId; /* applicable to STE-BT - not used */
}POSTPACK BTCOEX_SCO_CONFIG;
typedef PREPACK struct {
- A_UINT32 scoCyclesForceTrigger; /* Number SCO cycles after which
+ u32 scoCyclesForceTrigger; /* Number SCO cycles after which
force a pspoll. default = 10 */
- A_UINT32 scoDataResponseTimeout; /* Timeout Waiting for Downlink pkt
+ u32 scoDataResponseTimeout; /* Timeout Waiting for Downlink pkt
in response for ps-poll,
default = 20 msecs */
- A_UINT32 scoStompDutyCyleVal; /* not implemented */
+ u32 scoStompDutyCyleVal; /* not implemented */
- A_UINT32 scoStompDutyCyleMaxVal; /*Not implemented */
+ u32 scoStompDutyCyleMaxVal; /*Not implemented */
- A_UINT32 scoPsPollLatencyFraction; /* Fraction of idle
+ u32 scoPsPollLatencyFraction; /* Fraction of idle
period, within which
additional ps-polls can be queued
1 - 1/4 of idle duration
@@ -1549,29 +1549,29 @@ typedef PREPACK struct {
}POSTPACK BTCOEX_PSPOLLMODE_SCO_CONFIG;
typedef PREPACK struct {
- A_UINT32 scoStompCntIn100ms;/*max number of SCO stomp in 100ms allowed in
+ u32 scoStompCntIn100ms;/*max number of SCO stomp in 100ms allowed in
opt mode. If exceeds the configured value,
switch to ps-poll mode
default = 3 */
- A_UINT32 scoContStompMax; /* max number of continous stomp allowed in opt mode.
+ u32 scoContStompMax; /* max number of continous stomp allowed in opt mode.
if excedded switch to pspoll mode
default = 3 */
- A_UINT32 scoMinlowRateMbps; /* Low rate threshold */
+ u32 scoMinlowRateMbps; /* Low rate threshold */
- A_UINT32 scoLowRateCnt; /* number of low rate pkts (< scoMinlowRateMbps) allowed in 100 ms.
+ u32 scoLowRateCnt; /* number of low rate pkts (< scoMinlowRateMbps) allowed in 100 ms.
If exceeded switch/stay to ps-poll mode, lower stay in opt mode.
default = 36
*/
- A_UINT32 scoHighPktRatio; /*(Total Rx pkts in 100 ms + 1)/
+ u32 scoHighPktRatio; /*(Total Rx pkts in 100 ms + 1)/
((Total tx pkts in 100 ms - No of high rate pkts in 100 ms) + 1) in 100 ms,
if exceeded switch/stay in opt mode and if lower switch/stay in pspoll mode.
default = 5 (80% of high rates)
*/
- A_UINT32 scoMaxAggrSize; /* Max number of Rx subframes allowed in this mode. (Firmware re-negogiates
+ u32 scoMaxAggrSize; /* Max number of Rx subframes allowed in this mode. (Firmware re-negogiates
max number of aggregates if it was negogiated to higher value
default = 1
Recommended value Basic rate headsets = 1, EDR (2-EV3) =4.
@@ -1579,8 +1579,8 @@ typedef PREPACK struct {
}POSTPACK BTCOEX_OPTMODE_SCO_CONFIG;
typedef PREPACK struct {
- A_UINT32 scanInterval;
- A_UINT32 maxScanStompCnt;
+ u32 scanInterval;
+ u32 maxScanStompCnt;
}POSTPACK BTCOEX_WLANSCAN_SCO_CONFIG;
typedef PREPACK struct {
@@ -1608,7 +1608,7 @@ typedef PREPACK struct {
#define WMI_A2DP_CONFIG_FLAG_FIND_BT_ROLE (1 << 4)
typedef PREPACK struct {
- A_UINT32 a2dpFlags; /* A2DP Option flags:
+ u32 a2dpFlags; /* A2DP Option flags:
bits: meaning:
0 Allow Close Range Optimization
1 IS EDR capable
@@ -1616,19 +1616,19 @@ typedef PREPACK struct {
3 a2dp traffic is high priority
4 Fw detect the role of bluetooth.
*/
- A_UINT32 linkId; /* Applicable only to STE-BT - not used */
+ u32 linkId; /* Applicable only to STE-BT - not used */
}POSTPACK BTCOEX_A2DP_CONFIG;
typedef PREPACK struct {
- A_UINT32 a2dpWlanMaxDur; /* MAX time firmware uses the medium for
+ u32 a2dpWlanMaxDur; /* MAX time firmware uses the medium for
wlan, after it identifies the idle time
default (30 msecs) */
- A_UINT32 a2dpMinBurstCnt; /* Minimum number of bluetooth data frames
+ u32 a2dpMinBurstCnt; /* Minimum number of bluetooth data frames
to replenish Wlan Usage limit (default 3) */
- A_UINT32 a2dpDataRespTimeout; /* Max duration firmware waits for downlink
+ u32 a2dpDataRespTimeout; /* Max duration firmware waits for downlink
by stomping on bluetooth
after ps-poll is acknowledged.
default = 20 ms
@@ -1636,25 +1636,25 @@ typedef PREPACK struct {
}POSTPACK BTCOEX_PSPOLLMODE_A2DP_CONFIG;
typedef PREPACK struct {
- A_UINT32 a2dpMinlowRateMbps; /* Low rate threshold */
+ u32 a2dpMinlowRateMbps; /* Low rate threshold */
- A_UINT32 a2dpLowRateCnt; /* number of low rate pkts (< a2dpMinlowRateMbps) allowed in 100 ms.
+ u32 a2dpLowRateCnt; /* number of low rate pkts (< a2dpMinlowRateMbps) allowed in 100 ms.
If exceeded switch/stay to ps-poll mode, lower stay in opt mode.
default = 36
*/
- A_UINT32 a2dpHighPktRatio; /*(Total Rx pkts in 100 ms + 1)/
+ u32 a2dpHighPktRatio; /*(Total Rx pkts in 100 ms + 1)/
((Total tx pkts in 100 ms - No of high rate pkts in 100 ms) + 1) in 100 ms,
if exceeded switch/stay in opt mode and if lower switch/stay in pspoll mode.
default = 5 (80% of high rates)
*/
- A_UINT32 a2dpMaxAggrSize; /* Max number of Rx subframes allowed in this mode. (Firmware re-negogiates
+ u32 a2dpMaxAggrSize; /* Max number of Rx subframes allowed in this mode. (Firmware re-negogiates
max number of aggregates if it was negogiated to higher value
default = 1
Recommended value Basic rate headsets = 1, EDR (2-EV3) =8.
*/
- A_UINT32 a2dpPktStompCnt; /*number of a2dp pkts that can be stomped per burst.
+ u32 a2dpPktStompCnt; /*number of a2dp pkts that can be stomped per burst.
default = 6*/
}POSTPACK BTCOEX_OPTMODE_A2DP_CONFIG;
@@ -1683,15 +1683,15 @@ typedef PREPACK struct {
#define WMI_ACLCOEX_FLAGS_DISABLE_FW_DETECTION (1 << 1)
typedef PREPACK struct {
- A_UINT32 aclWlanMediumDur; /* Wlan usage time during Acl (non-a2dp)
+ u32 aclWlanMediumDur; /* Wlan usage time during Acl (non-a2dp)
coexistence (default 30 msecs)
*/
- A_UINT32 aclBtMediumDur; /* Bt usage time during acl coexistence
+ u32 aclBtMediumDur; /* Bt usage time during acl coexistence
(default 30 msecs)
*/
- A_UINT32 aclDetectTimeout; /* BT activity observation time limit.
+ u32 aclDetectTimeout; /* BT activity observation time limit.
In this time duration, number of bt pkts are counted.
If the Cnt reaches "aclPktCntLowerLimit" value
for "aclIterToEnableCoex" iteration continuously,
@@ -1703,7 +1703,7 @@ typedef PREPACK struct {
-default 100 msecs
*/
- A_UINT32 aclPktCntLowerLimit; /* Acl Pkt Cnt to be received in duration of
+ u32 aclPktCntLowerLimit; /* Acl Pkt Cnt to be received in duration of
"aclDetectTimeout" for
"aclIterForEnDis" times to enabling ACL coex.
Similar logic is used to disable acl coexistence.
@@ -1713,28 +1713,28 @@ typedef PREPACK struct {
default = 10
*/
- A_UINT32 aclIterForEnDis; /* number of Iteration of "aclPktCntLowerLimit" for Enabling and
+ u32 aclIterForEnDis; /* number of Iteration of "aclPktCntLowerLimit" for Enabling and
Disabling Acl Coexistence.
default = 3
*/
- A_UINT32 aclPktCntUpperLimit; /* This is upperBound limit, if there is more than
+ u32 aclPktCntUpperLimit; /* This is upperBound limit, if there is more than
"aclPktCntUpperLimit" seen in "aclDetectTimeout",
ACL coexistence is enabled right away.
- default 15*/
- A_UINT32 aclCoexFlags; /* A2DP Option flags:
+ u32 aclCoexFlags; /* A2DP Option flags:
bits: meaning:
0 Allow Close Range Optimization
1 disable Firmware detection
(Currently supported configuration is aclCoexFlags =0)
*/
- A_UINT32 linkId; /* Applicable only for STE-BT - not used */
+ u32 linkId; /* Applicable only for STE-BT - not used */
}POSTPACK BTCOEX_ACLCOEX_CONFIG;
typedef PREPACK struct {
- A_UINT32 aclDataRespTimeout; /* Max duration firmware waits for downlink
+ u32 aclDataRespTimeout; /* Max duration firmware waits for downlink
by stomping on bluetooth
after ps-poll is acknowledged.
default = 20 ms */
@@ -1744,11 +1744,11 @@ typedef PREPACK struct {
/* Not implemented yet*/
typedef PREPACK struct {
- A_UINT32 aclCoexMinlowRateMbps;
- A_UINT32 aclCoexLowRateCnt;
- A_UINT32 aclCoexHighPktRatio;
- A_UINT32 aclCoexMaxAggrSize;
- A_UINT32 aclPktStompCnt;
+ u32 aclCoexMinlowRateMbps;
+ u32 aclCoexLowRateCnt;
+ u32 aclCoexHighPktRatio;
+ u32 aclCoexMaxAggrSize;
+ u32 aclPktStompCnt;
}POSTPACK BTCOEX_OPTMODE_ACLCOEX_CONFIG;
typedef PREPACK struct {
@@ -1766,39 +1766,39 @@ typedef enum {
}WMI_BTCOEX_BT_PROFILE;
typedef PREPACK struct {
- A_UINT32 btProfileType;
- A_UINT32 btOperatingStatus;
- A_UINT32 btLinkId;
+ u32 btProfileType;
+ u32 btOperatingStatus;
+ u32 btLinkId;
}WMI_SET_BTCOEX_BT_OPERATING_STATUS_CMD;
/*--------------------- WMI_SET_BTCOEX_DEBUG_CMDID ---------------------*/
/* Used for firmware development and debugging */
typedef PREPACK struct {
- A_UINT32 btcoexDbgParam1;
- A_UINT32 btcoexDbgParam2;
- A_UINT32 btcoexDbgParam3;
- A_UINT32 btcoexDbgParam4;
- A_UINT32 btcoexDbgParam5;
+ u32 btcoexDbgParam1;
+ u32 btcoexDbgParam2;
+ u32 btcoexDbgParam3;
+ u32 btcoexDbgParam4;
+ u32 btcoexDbgParam5;
}WMI_SET_BTCOEX_DEBUG_CMD;
/*---------------------WMI_GET_BTCOEX_CONFIG_CMDID --------------------- */
/* Command to firmware to get configuration parameters of the bt profile
* reported via WMI_BTCOEX_CONFIG_EVENTID */
typedef PREPACK struct {
- A_UINT32 btProfileType; /* 1 - SCO
+ u32 btProfileType; /* 1 - SCO
2 - A2DP
3 - INQUIRY_PAGE
4 - ACLCOEX
*/
- A_UINT32 linkId; /* not used */
+ u32 linkId; /* not used */
}WMI_GET_BTCOEX_CONFIG_CMD;
/*------------------WMI_REPORT_BTCOEX_CONFIG_EVENTID------------------- */
/* Event from firmware to host, sent in response to WMI_GET_BTCOEX_CONFIG_CMDID
* */
typedef PREPACK struct {
- A_UINT32 btProfileType;
- A_UINT32 linkId; /* not used */
+ u32 btProfileType;
+ u32 linkId; /* not used */
PREPACK union {
WMI_SET_BTCOEX_SCO_CONFIG_CMD scoConfigCmd;
WMI_SET_BTCOEX_A2DP_CONFIG_CMD a2dpConfigCmd;
@@ -1810,32 +1810,32 @@ typedef PREPACK struct {
/*------------- WMI_REPORT_BTCOEX_BTCOEX_STATS_EVENTID--------------------*/
/* Used for firmware development and debugging*/
typedef PREPACK struct {
- A_UINT32 highRatePktCnt;
- A_UINT32 firstBmissCnt;
- A_UINT32 psPollFailureCnt;
- A_UINT32 nullFrameFailureCnt;
- A_UINT32 optModeTransitionCnt;
+ u32 highRatePktCnt;
+ u32 firstBmissCnt;
+ u32 psPollFailureCnt;
+ u32 nullFrameFailureCnt;
+ u32 optModeTransitionCnt;
}BTCOEX_GENERAL_STATS;
typedef PREPACK struct {
- A_UINT32 scoStompCntAvg;
- A_UINT32 scoStompIn100ms;
- A_UINT32 scoMaxContStomp;
- A_UINT32 scoAvgNoRetries;
- A_UINT32 scoMaxNoRetriesIn100ms;
+ u32 scoStompCntAvg;
+ u32 scoStompIn100ms;
+ u32 scoMaxContStomp;
+ u32 scoAvgNoRetries;
+ u32 scoMaxNoRetriesIn100ms;
}BTCOEX_SCO_STATS;
typedef PREPACK struct {
- A_UINT32 a2dpBurstCnt;
- A_UINT32 a2dpMaxBurstCnt;
- A_UINT32 a2dpAvgIdletimeIn100ms;
- A_UINT32 a2dpAvgStompCnt;
+ u32 a2dpBurstCnt;
+ u32 a2dpMaxBurstCnt;
+ u32 a2dpAvgIdletimeIn100ms;
+ u32 a2dpAvgStompCnt;
}BTCOEX_A2DP_STATS;
typedef PREPACK struct {
- A_UINT32 aclPktCntInBtTime;
- A_UINT32 aclStompCntInWlanTime;
- A_UINT32 aclPktCntIn100ms;
+ u32 aclPktCntInBtTime;
+ u32 aclStompCntInWlanTime;
+ u32 aclPktCntIn100ms;
}BTCOEX_ACLCOEX_STATS;
typedef PREPACK struct {
@@ -1848,7 +1848,7 @@ typedef PREPACK struct {
/*--------------------------END OF BTCOEX -------------------------------------*/
typedef PREPACK struct {
- A_UINT32 sleepState;
+ u32 sleepState;
}WMI_REPORT_SLEEP_STATE_EVENT;
typedef enum {
@@ -1861,7 +1861,7 @@ typedef enum {
} TARGET_EVENT_REPORT_CONFIG;
typedef PREPACK struct {
- A_UINT32 evtConfig;
+ u32 evtConfig;
} POSTPACK WMI_SET_TARGET_EVENT_REPORT_CMD;
@@ -1981,8 +1981,8 @@ typedef PREPACK struct {
} POSTPACK WMI_READY_EVENT_1;
typedef PREPACK struct {
- A_UINT32 sw_version;
- A_UINT32 abi_version;
+ u32 sw_version;
+ u32 abi_version;
u8 macaddr[ATH_MAC_LEN];
u8 phyCapability; /* WMI_PHY_CAPABILITY */
} POSTPACK WMI_READY_EVENT_2;
@@ -2006,7 +2006,7 @@ typedef PREPACK struct {
u8 bssid[ATH_MAC_LEN];
u16 listenInterval;
u16 beaconInterval;
- A_UINT32 networkType;
+ u32 networkType;
u8 beaconIeLen;
u8 assocReqLen;
u8 assocRespLen;
@@ -2064,7 +2064,7 @@ typedef PREPACK struct {
u8 snr;
A_INT16 rssi;
u8 bssid[ATH_MAC_LEN];
- A_UINT32 ieMask;
+ u32 ieMask;
} POSTPACK WMI_BSS_INFO_HDR;
/*
@@ -2101,7 +2101,7 @@ typedef PREPACK struct {
* New Regulatory Domain Event
*/
typedef PREPACK struct {
- A_UINT32 regDomain;
+ u32 regDomain;
} POSTPACK WMI_REG_DOMAIN_EVENT;
typedef PREPACK struct {
@@ -2216,56 +2216,56 @@ typedef PREPACK struct {
* Reporting statistics.
*/
typedef PREPACK struct {
- A_UINT32 tx_packets;
- A_UINT32 tx_bytes;
- A_UINT32 tx_unicast_pkts;
- A_UINT32 tx_unicast_bytes;
- A_UINT32 tx_multicast_pkts;
- A_UINT32 tx_multicast_bytes;
- A_UINT32 tx_broadcast_pkts;
- A_UINT32 tx_broadcast_bytes;
- A_UINT32 tx_rts_success_cnt;
- A_UINT32 tx_packet_per_ac[4];
- A_UINT32 tx_errors_per_ac[4];
-
- A_UINT32 tx_errors;
- A_UINT32 tx_failed_cnt;
- A_UINT32 tx_retry_cnt;
- A_UINT32 tx_mult_retry_cnt;
- A_UINT32 tx_rts_fail_cnt;
+ u32 tx_packets;
+ u32 tx_bytes;
+ u32 tx_unicast_pkts;
+ u32 tx_unicast_bytes;
+ u32 tx_multicast_pkts;
+ u32 tx_multicast_bytes;
+ u32 tx_broadcast_pkts;
+ u32 tx_broadcast_bytes;
+ u32 tx_rts_success_cnt;
+ u32 tx_packet_per_ac[4];
+ u32 tx_errors_per_ac[4];
+
+ u32 tx_errors;
+ u32 tx_failed_cnt;
+ u32 tx_retry_cnt;
+ u32 tx_mult_retry_cnt;
+ u32 tx_rts_fail_cnt;
A_INT32 tx_unicast_rate;
}POSTPACK tx_stats_t;
typedef PREPACK struct {
- A_UINT32 rx_packets;
- A_UINT32 rx_bytes;
- A_UINT32 rx_unicast_pkts;
- A_UINT32 rx_unicast_bytes;
- A_UINT32 rx_multicast_pkts;
- A_UINT32 rx_multicast_bytes;
- A_UINT32 rx_broadcast_pkts;
- A_UINT32 rx_broadcast_bytes;
- A_UINT32 rx_fragment_pkt;
-
- A_UINT32 rx_errors;
- A_UINT32 rx_crcerr;
- A_UINT32 rx_key_cache_miss;
- A_UINT32 rx_decrypt_err;
- A_UINT32 rx_duplicate_frames;
+ u32 rx_packets;
+ u32 rx_bytes;
+ u32 rx_unicast_pkts;
+ u32 rx_unicast_bytes;
+ u32 rx_multicast_pkts;
+ u32 rx_multicast_bytes;
+ u32 rx_broadcast_pkts;
+ u32 rx_broadcast_bytes;
+ u32 rx_fragment_pkt;
+
+ u32 rx_errors;
+ u32 rx_crcerr;
+ u32 rx_key_cache_miss;
+ u32 rx_decrypt_err;
+ u32 rx_duplicate_frames;
A_INT32 rx_unicast_rate;
}POSTPACK rx_stats_t;
typedef PREPACK struct {
- A_UINT32 tkip_local_mic_failure;
- A_UINT32 tkip_counter_measures_invoked;
- A_UINT32 tkip_replays;
- A_UINT32 tkip_format_errors;
- A_UINT32 ccmp_format_errors;
- A_UINT32 ccmp_replays;
+ u32 tkip_local_mic_failure;
+ u32 tkip_counter_measures_invoked;
+ u32 tkip_replays;
+ u32 tkip_format_errors;
+ u32 ccmp_format_errors;
+ u32 ccmp_replays;
}POSTPACK tkip_ccmp_stats_t;
typedef PREPACK struct {
- A_UINT32 power_save_failure_cnt;
+ u32 power_save_failure_cnt;
u16 stop_tx_failure_cnt;
u16 atim_tx_failure_cnt;
u16 atim_rx_failure_cnt;
@@ -2273,8 +2273,8 @@ typedef PREPACK struct {
}POSTPACK pm_stats_t;
typedef PREPACK struct {
- A_UINT32 cs_bmiss_cnt;
- A_UINT32 cs_lowRssi_cnt;
+ u32 cs_bmiss_cnt;
+ u32 cs_lowRssi_cnt;
u16 cs_connect_cnt;
u16 cs_disconnect_cnt;
A_INT16 cs_aveBeacon_rssi;
@@ -2292,20 +2292,20 @@ typedef PREPACK struct {
}POSTPACK wlan_net_stats_t;
typedef PREPACK struct {
- A_UINT32 arp_received;
- A_UINT32 arp_matched;
- A_UINT32 arp_replied;
+ u32 arp_received;
+ u32 arp_matched;
+ u32 arp_replied;
} POSTPACK arp_stats_t;
typedef PREPACK struct {
- A_UINT32 wow_num_pkts_dropped;
+ u32 wow_num_pkts_dropped;
u16 wow_num_events_discarded;
u8 wow_num_host_pkt_wakeups;
u8 wow_num_host_event_wakeups;
} POSTPACK wlan_wow_stats_t;
typedef PREPACK struct {
- A_UINT32 lqVal;
+ u32 lqVal;
A_INT32 noise_floor_calibation;
pm_stats_t pmStats;
wlan_net_stats_t txrxStats;
@@ -2353,7 +2353,7 @@ typedef enum{
} WMI_TARGET_ERROR_VAL;
typedef PREPACK struct {
- A_UINT32 errorVal;
+ u32 errorVal;
}POSTPACK WMI_TARGET_ERROR_REPORT_EVENT;
typedef PREPACK struct {
@@ -2522,43 +2522,43 @@ typedef PREPACK struct {
*
* Get fix rates cmd uses same definition as set fix rates cmd
*/
-#define FIX_RATE_1Mb ((A_UINT32)0x1)
-#define FIX_RATE_2Mb ((A_UINT32)0x2)
-#define FIX_RATE_5_5Mb ((A_UINT32)0x4)
-#define FIX_RATE_11Mb ((A_UINT32)0x8)
-#define FIX_RATE_6Mb ((A_UINT32)0x10)
-#define FIX_RATE_9Mb ((A_UINT32)0x20)
-#define FIX_RATE_12Mb ((A_UINT32)0x40)
-#define FIX_RATE_18Mb ((A_UINT32)0x80)
-#define FIX_RATE_24Mb ((A_UINT32)0x100)
-#define FIX_RATE_36Mb ((A_UINT32)0x200)
-#define FIX_RATE_48Mb ((A_UINT32)0x400)
-#define FIX_RATE_54Mb ((A_UINT32)0x800)
-#define FIX_RATE_MCS_0_20 ((A_UINT32)0x1000)
-#define FIX_RATE_MCS_1_20 ((A_UINT32)0x2000)
-#define FIX_RATE_MCS_2_20 ((A_UINT32)0x4000)
-#define FIX_RATE_MCS_3_20 ((A_UINT32)0x8000)
-#define FIX_RATE_MCS_4_20 ((A_UINT32)0x10000)
-#define FIX_RATE_MCS_5_20 ((A_UINT32)0x20000)
-#define FIX_RATE_MCS_6_20 ((A_UINT32)0x40000)
-#define FIX_RATE_MCS_7_20 ((A_UINT32)0x80000)
-#define FIX_RATE_MCS_0_40 ((A_UINT32)0x100000)
-#define FIX_RATE_MCS_1_40 ((A_UINT32)0x200000)
-#define FIX_RATE_MCS_2_40 ((A_UINT32)0x400000)
-#define FIX_RATE_MCS_3_40 ((A_UINT32)0x800000)
-#define FIX_RATE_MCS_4_40 ((A_UINT32)0x1000000)
-#define FIX_RATE_MCS_5_40 ((A_UINT32)0x2000000)
-#define FIX_RATE_MCS_6_40 ((A_UINT32)0x4000000)
-#define FIX_RATE_MCS_7_40 ((A_UINT32)0x8000000)
-
-typedef PREPACK struct {
- A_UINT32 fixRateMask; /* see WMI_BIT_RATE */
+#define FIX_RATE_1Mb ((u32)0x1)
+#define FIX_RATE_2Mb ((u32)0x2)
+#define FIX_RATE_5_5Mb ((u32)0x4)
+#define FIX_RATE_11Mb ((u32)0x8)
+#define FIX_RATE_6Mb ((u32)0x10)
+#define FIX_RATE_9Mb ((u32)0x20)
+#define FIX_RATE_12Mb ((u32)0x40)
+#define FIX_RATE_18Mb ((u32)0x80)
+#define FIX_RATE_24Mb ((u32)0x100)
+#define FIX_RATE_36Mb ((u32)0x200)
+#define FIX_RATE_48Mb ((u32)0x400)
+#define FIX_RATE_54Mb ((u32)0x800)
+#define FIX_RATE_MCS_0_20 ((u32)0x1000)
+#define FIX_RATE_MCS_1_20 ((u32)0x2000)
+#define FIX_RATE_MCS_2_20 ((u32)0x4000)
+#define FIX_RATE_MCS_3_20 ((u32)0x8000)
+#define FIX_RATE_MCS_4_20 ((u32)0x10000)
+#define FIX_RATE_MCS_5_20 ((u32)0x20000)
+#define FIX_RATE_MCS_6_20 ((u32)0x40000)
+#define FIX_RATE_MCS_7_20 ((u32)0x80000)
+#define FIX_RATE_MCS_0_40 ((u32)0x100000)
+#define FIX_RATE_MCS_1_40 ((u32)0x200000)
+#define FIX_RATE_MCS_2_40 ((u32)0x400000)
+#define FIX_RATE_MCS_3_40 ((u32)0x800000)
+#define FIX_RATE_MCS_4_40 ((u32)0x1000000)
+#define FIX_RATE_MCS_5_40 ((u32)0x2000000)
+#define FIX_RATE_MCS_6_40 ((u32)0x4000000)
+#define FIX_RATE_MCS_7_40 ((u32)0x8000000)
+
+typedef PREPACK struct {
+ u32 fixRateMask; /* see WMI_BIT_RATE */
} POSTPACK WMI_FIX_RATES_CMD, WMI_FIX_RATES_REPLY;
typedef PREPACK struct {
u8 bEnableMask;
u8 frameType; /*type and subtype*/
- A_UINT32 frameRateMask; /* see WMI_BIT_RATE */
+ u32 frameRateMask; /* see WMI_BIT_RATE */
} POSTPACK WMI_FRAME_RATES_CMD, WMI_FRAME_RATES_REPLY;
/*
@@ -2594,10 +2594,10 @@ typedef enum {
} ROAM_DATA_TYPE;
typedef PREPACK struct {
- A_UINT32 disassoc_time;
- A_UINT32 no_txrx_time;
- A_UINT32 assoc_time;
- A_UINT32 allow_txrx_time;
+ u32 disassoc_time;
+ u32 no_txrx_time;
+ u32 assoc_time;
+ u32 allow_txrx_time;
u8 disassoc_bssid[ATH_MAC_LEN];
A_INT8 disassoc_bss_rssi;
u8 assoc_bssid[ATH_MAC_LEN];
@@ -2713,7 +2713,7 @@ typedef PREPACK struct {
#define MAX_IP_ADDRS 2
typedef PREPACK struct {
- A_UINT32 ips[MAX_IP_ADDRS]; /* IP in Network Byte Order */
+ u32 ips[MAX_IP_ADDRS]; /* IP in Network Byte Order */
} POSTPACK WMI_SET_IP_CMD;
typedef PREPACK struct {
@@ -2769,7 +2769,7 @@ typedef PREPACK struct {
#define WMI_AKMP_MULTI_PMKID_EN 0x000001
typedef PREPACK struct {
- A_UINT32 akmpInfo;
+ u32 akmpInfo;
} POSTPACK WMI_SET_AKMP_PARAMS_CMD;
typedef PREPACK struct {
@@ -2782,7 +2782,7 @@ typedef PREPACK struct {
#define WMI_MAX_PMKID_CACHE 8
typedef PREPACK struct {
- A_UINT32 numPMKID;
+ u32 numPMKID;
WMI_PMKID pmkidList[WMI_MAX_PMKID_CACHE];
} POSTPACK WMI_SET_PMKID_LIST_CMD;
@@ -2791,18 +2791,18 @@ typedef PREPACK struct {
* Following the Number of PMKIDs is the list of PMKIDs
*/
typedef PREPACK struct {
- A_UINT32 numPMKID;
+ u32 numPMKID;
u8 bssidList[ATH_MAC_LEN][1];
WMI_PMKID pmkidList[1];
} POSTPACK WMI_PMKID_LIST_REPLY;
typedef PREPACK struct {
u16 oldChannel;
- A_UINT32 newChannel;
+ u32 newChannel;
} POSTPACK WMI_CHANNEL_CHANGE_EVENT;
typedef PREPACK struct {
- A_UINT32 version;
+ u32 version;
} POSTPACK WMI_WLAN_VERSION_EVENT;
@@ -2898,8 +2898,8 @@ typedef PREPACK struct {
u8 rateIdx; /* rate index on successful transmission */
u8 ackFailures; /* number of ACK failures in tx attempt */
#if 0 /* optional params currently ommitted. */
- A_UINT32 queueDelay; // usec delay measured Tx Start time - host delivery time
- A_UINT32 mediaDelay; // usec delay measured ACK rx time - host delivery time
+ u32 queueDelay; // usec delay measured Tx Start time - host delivery time
+ u32 mediaDelay; // usec delay measured ACK rx time - host delivery time
#endif
} POSTPACK TX_COMPLETE_MSG_V1; /* version 1 of tx complete msg */
@@ -3001,12 +3001,12 @@ typedef PREPACK struct {
} POSTPACK WMI_AP_SET_MLME_CMD;
typedef PREPACK struct {
- A_UINT32 period;
+ u32 period;
} POSTPACK WMI_AP_CONN_INACT_CMD;
typedef PREPACK struct {
- A_UINT32 period_min;
- A_UINT32 dwell_ms;
+ u32 period_min;
+ u32 dwell_ms;
} POSTPACK WMI_AP_PROT_SCAN_TIME_CMD;
typedef PREPACK struct {
@@ -3039,11 +3039,11 @@ typedef PREPACK struct {
} POSTPACK WMI_SET_HT_OP_CMD;
typedef PREPACK struct {
- A_UINT32 rateMasks[8];
+ u32 rateMasks[8];
} POSTPACK WMI_SET_TX_SELECT_RATES_CMD;
typedef PREPACK struct {
- A_UINT32 sgiMask;
+ u32 sgiMask;
u8 sgiPERThreshold;
} POSTPACK WMI_SET_TX_SGI_PARAM_CMD;
@@ -3051,7 +3051,7 @@ typedef PREPACK struct {
#define DEFAULT_SGI_PER 10
typedef PREPACK struct {
- A_UINT32 rateField; /* 1 bit per rate corresponding to index */
+ u32 rateField; /* 1 bit per rate corresponding to index */
u8 id;
u8 shortTrys;
u8 longTrys;
@@ -3078,25 +3078,25 @@ typedef PREPACK struct {
} POSTPACK WMI_PSPOLL_EVENT;
typedef PREPACK struct {
- A_UINT32 tx_bytes;
- A_UINT32 tx_pkts;
- A_UINT32 tx_error;
- A_UINT32 tx_discard;
- A_UINT32 rx_bytes;
- A_UINT32 rx_pkts;
- A_UINT32 rx_error;
- A_UINT32 rx_discard;
- A_UINT32 aid;
+ u32 tx_bytes;
+ u32 tx_pkts;
+ u32 tx_error;
+ u32 tx_discard;
+ u32 rx_bytes;
+ u32 rx_pkts;
+ u32 rx_error;
+ u32 rx_discard;
+ u32 aid;
} POSTPACK WMI_PER_STA_STAT;
#define AP_GET_STATS 0
#define AP_CLEAR_STATS 1
typedef PREPACK struct {
- A_UINT32 action;
+ u32 action;
WMI_PER_STA_STAT sta[AP_MAX_NUM_STA+1];
} POSTPACK WMI_AP_MODE_STAT;
-#define WMI_AP_MODE_STAT_SIZE(numSta) (sizeof(A_UINT32) + ((numSta + 1) * sizeof(WMI_PER_STA_STAT)))
+#define WMI_AP_MODE_STAT_SIZE(numSta) (sizeof(u32) + ((numSta + 1) * sizeof(WMI_PER_STA_STAT)))
#define AP_11BG_RATESET1 1
#define AP_11BG_RATESET2 2
diff --git a/drivers/staging/ath6kl/include/common/wmi_thin.h b/drivers/staging/ath6kl/include/common/wmi_thin.h
index dee5e8aae425..41f2b9ba1021 100644
--- a/drivers/staging/ath6kl/include/common/wmi_thin.h
+++ b/drivers/staging/ath6kl/include/common/wmi_thin.h
@@ -119,14 +119,14 @@ typedef PREPACK struct {
* frames that require partial MAC header construction. These rules
* are used by the target to indicate which fields need to be written. */
typedef PREPACK struct {
- A_UINT32 rules; /* combination of WMI_WRT_... values */
+ u32 rules; /* combination of WMI_WRT_... values */
} POSTPACK WMI_THIN_CONFIG_TX_MAC_RULES;
/* WMI_THIN_CONFIG_RX_FILTER_RULES -- Used to configure behavior for received
* frames as to which frames should get forwarded to the host and which
* should get processed internally. */
typedef PREPACK struct {
- A_UINT32 rules; /* combination of WMI_FILT_... values */
+ u32 rules; /* combination of WMI_FILT_... values */
} POSTPACK WMI_THIN_CONFIG_RX_FILTER_RULES;
/* WMI_THIN_CONFIG_CMD -- Used to contain some combination of the above
@@ -138,7 +138,7 @@ typedef PREPACK struct {
#define WMI_THIN_CFG_DECRYPT 0x00000002
#define WMI_THIN_CFG_MAC_RULES 0x00000004
#define WMI_THIN_CFG_FILTER_RULES 0x00000008
- A_UINT32 cfgField; /* combination of WMI_THIN_CFG_... describes contents of config command */
+ u32 cfgField; /* combination of WMI_THIN_CFG_... describes contents of config command */
u16 length; /* length in bytes of appended sub-commands */
u8 reserved[2]; /* align padding */
} POSTPACK WMI_THIN_CONFIG_CMD;
@@ -180,7 +180,7 @@ typedef PREPACK struct {
} POSTPACK WMI_THIN_MIB_STA_MAC;
typedef PREPACK struct {
- A_UINT32 time; // units == msec
+ u32 time; // units == msec
} POSTPACK WMI_THIN_MIB_RX_LIFE_TIME;
typedef PREPACK struct {
@@ -188,7 +188,7 @@ typedef PREPACK struct {
} POSTPACK WMI_THIN_MIB_CTS_TO_SELF;
typedef PREPACK struct {
- A_UINT32 time; // units == usec
+ u32 time; // units == usec
} POSTPACK WMI_THIN_MIB_SLOT_TIME;
typedef PREPACK struct {
@@ -204,7 +204,7 @@ typedef PREPACK struct {
typedef PREPACK struct {
#define FRAME_FILTER_PROMISCUOUS 0x00000001
#define FRAME_FILTER_BSSID 0x00000002
- A_UINT32 filterMask;
+ u32 filterMask;
} POSTPACK WMI_THIN_MIB_RXFRAME_FILTER;
@@ -231,13 +231,13 @@ typedef PREPACK struct {
} POSTPACK WMI_THIN_MIB_BEACON_FILTER_TABLE_HEADER;
typedef PREPACK struct {
- A_UINT32 count; /* num beacons between deliveries */
+ u32 count; /* num beacons between deliveries */
u8 enable;
u8 reserved[3];
} POSTPACK WMI_THIN_MIB_BEACON_FILTER;
typedef PREPACK struct {
- A_UINT32 count; /* num consec lost beacons after which send event */
+ u32 count; /* num consec lost beacons after which send event */
} POSTPACK WMI_THIN_MIB_BEACON_LOST_COUNT;
typedef PREPACK struct {
@@ -249,9 +249,9 @@ typedef PREPACK struct {
typedef PREPACK struct {
- A_UINT32 cap;
- A_UINT32 rxRateField;
- A_UINT32 beamForming;
+ u32 cap;
+ u32 rxRateField;
+ u32 beamForming;
u8 addr[ATH_MAC_LEN];
u8 enable;
u8 stbc;
@@ -262,8 +262,8 @@ typedef PREPACK struct {
} POSTPACK WMI_THIN_MIB_HT_CAP;
typedef PREPACK struct {
- A_UINT32 infoField;
- A_UINT32 basicRateField;
+ u32 infoField;
+ u32 basicRateField;
u8 protection;
u8 secondChanneloffset;
u8 channelWidth;
@@ -301,8 +301,8 @@ typedef PREPACK struct {
} POSTPACK WMI_THIN_GET_MIB_CMD;
typedef PREPACK struct {
- A_UINT32 basicRateMask; /* bit mask of basic rates */
- A_UINT32 beaconIntval; /* TUs */
+ u32 basicRateMask; /* bit mask of basic rates */
+ u32 beaconIntval; /* TUs */
u16 atimWindow; /* TUs */
u16 channel; /* frequency in Mhz */
u8 networkType; /* INFRA_NETWORK | ADHOC_NETWORK */
diff --git a/drivers/staging/ath6kl/include/common/wmix.h b/drivers/staging/ath6kl/include/common/wmix.h
index 7dd5434136a2..5ebb8285d135 100644
--- a/drivers/staging/ath6kl/include/common/wmix.h
+++ b/drivers/staging/ath6kl/include/common/wmix.h
@@ -55,7 +55,7 @@ extern "C" {
* WMI_EVENT_ID=WMI_EXTENSION_EVENTID.
*/
typedef PREPACK struct {
- A_UINT32 commandId;
+ u32 commandId;
} POSTPACK WMIX_CMD_HDR;
typedef enum {
@@ -96,10 +96,10 @@ typedef enum {
* DataSet Open Request Event
*/
typedef PREPACK struct {
- A_UINT32 dset_id;
- A_UINT32 targ_dset_handle; /* echo'ed, not used by Host, */
- A_UINT32 targ_reply_fn; /* echo'ed, not used by Host, */
- A_UINT32 targ_reply_arg; /* echo'ed, not used by Host, */
+ u32 dset_id;
+ u32 targ_dset_handle; /* echo'ed, not used by Host, */
+ u32 targ_reply_fn; /* echo'ed, not used by Host, */
+ u32 targ_reply_arg; /* echo'ed, not used by Host, */
} POSTPACK WMIX_DSETOPENREQ_EVENT;
/*
@@ -107,7 +107,7 @@ typedef PREPACK struct {
* DataSet Close Event
*/
typedef PREPACK struct {
- A_UINT32 access_cookie;
+ u32 access_cookie;
} POSTPACK WMIX_DSETCLOSE_EVENT;
/*
@@ -115,30 +115,30 @@ typedef PREPACK struct {
* DataSet Data Request Event
*/
typedef PREPACK struct {
- A_UINT32 access_cookie;
- A_UINT32 offset;
- A_UINT32 length;
- A_UINT32 targ_buf; /* echo'ed, not used by Host, */
- A_UINT32 targ_reply_fn; /* echo'ed, not used by Host, */
- A_UINT32 targ_reply_arg; /* echo'ed, not used by Host, */
+ u32 access_cookie;
+ u32 offset;
+ u32 length;
+ u32 targ_buf; /* echo'ed, not used by Host, */
+ u32 targ_reply_fn; /* echo'ed, not used by Host, */
+ u32 targ_reply_arg; /* echo'ed, not used by Host, */
} POSTPACK WMIX_DSETDATAREQ_EVENT;
typedef PREPACK struct {
- A_UINT32 status;
- A_UINT32 targ_dset_handle;
- A_UINT32 targ_reply_fn;
- A_UINT32 targ_reply_arg;
- A_UINT32 access_cookie;
- A_UINT32 size;
- A_UINT32 version;
+ u32 status;
+ u32 targ_dset_handle;
+ u32 targ_reply_fn;
+ u32 targ_reply_arg;
+ u32 access_cookie;
+ u32 size;
+ u32 version;
} POSTPACK WMIX_DSETOPEN_REPLY_CMD;
typedef PREPACK struct {
- A_UINT32 status;
- A_UINT32 targ_buf;
- A_UINT32 targ_reply_fn;
- A_UINT32 targ_reply_arg;
- A_UINT32 length;
+ u32 status;
+ u32 targ_buf;
+ u32 targ_reply_fn;
+ u32 targ_reply_arg;
+ u32 length;
u8 buf[1];
} POSTPACK WMIX_DSETDATA_REPLY_CMD;
@@ -160,10 +160,10 @@ typedef PREPACK struct {
* clear/disable or disable/enable, results are undefined.
*/
typedef PREPACK struct {
- A_UINT32 set_mask; /* pins to set */
- A_UINT32 clear_mask; /* pins to clear */
- A_UINT32 enable_mask; /* pins to enable for output */
- A_UINT32 disable_mask; /* pins to disable/tristate */
+ u32 set_mask; /* pins to set */
+ u32 clear_mask; /* pins to clear */
+ u32 enable_mask; /* pins to enable for output */
+ u32 disable_mask; /* pins to disable/tristate */
} POSTPACK WMIX_GPIO_OUTPUT_SET_CMD;
/*
@@ -172,13 +172,13 @@ typedef PREPACK struct {
* platform-dependent header.
*/
typedef PREPACK struct {
- A_UINT32 gpioreg_id; /* GPIO register ID */
- A_UINT32 value; /* value to write */
+ u32 gpioreg_id; /* GPIO register ID */
+ u32 value; /* value to write */
} POSTPACK WMIX_GPIO_REGISTER_SET_CMD;
/* Get a GPIO register. For debug/exceptional cases. */
typedef PREPACK struct {
- A_UINT32 gpioreg_id; /* GPIO register to read */
+ u32 gpioreg_id; /* GPIO register to read */
} POSTPACK WMIX_GPIO_REGISTER_GET_CMD;
/*
@@ -187,7 +187,7 @@ typedef PREPACK struct {
* were delivered in an earlier WMIX_GPIO_INTR_EVENT message.
*/
typedef PREPACK struct {
- A_UINT32 ack_mask; /* interrupts to acknowledge */
+ u32 ack_mask; /* interrupts to acknowledge */
} POSTPACK WMIX_GPIO_INTR_ACK_CMD;
/*
@@ -197,8 +197,8 @@ typedef PREPACK struct {
* use of a GPIO interrupt as a Data Valid signal for other GPIO pins.
*/
typedef PREPACK struct {
- A_UINT32 intr_mask; /* pending GPIO interrupts */
- A_UINT32 input_values; /* recent GPIO input values */
+ u32 intr_mask; /* pending GPIO interrupts */
+ u32 input_values; /* recent GPIO input values */
} POSTPACK WMIX_GPIO_INTR_EVENT;
/*
@@ -217,8 +217,8 @@ typedef PREPACK struct {
* simplify Host GPIO support.
*/
typedef PREPACK struct {
- A_UINT32 value;
- A_UINT32 reg_id;
+ u32 value;
+ u32 reg_id;
} POSTPACK WMIX_GPIO_DATA_EVENT;
/*
@@ -230,8 +230,8 @@ typedef PREPACK struct {
* Heartbeat Challenge Response command
*/
typedef PREPACK struct {
- A_UINT32 cookie;
- A_UINT32 source;
+ u32 cookie;
+ u32 source;
} POSTPACK WMIX_HB_CHALLENGE_RESP_CMD;
/*
@@ -249,12 +249,12 @@ typedef PREPACK struct {
*/
typedef PREPACK struct {
- A_UINT32 period; /* Time (in 30.5us ticks) between samples */
- A_UINT32 nbins;
+ u32 period; /* Time (in 30.5us ticks) between samples */
+ u32 nbins;
} POSTPACK WMIX_PROF_CFG_CMD;
typedef PREPACK struct {
- A_UINT32 addr;
+ u32 addr;
} POSTPACK WMIX_PROF_ADDR_SET_CMD;
/*
@@ -264,8 +264,8 @@ typedef PREPACK struct {
* count set to the corresponding count
*/
typedef PREPACK struct {
- A_UINT32 addr;
- A_UINT32 count;
+ u32 addr;
+ u32 count;
} POSTPACK WMIX_PROF_COUNT_EVENT;
#ifndef ATH_TARGET
diff --git a/drivers/staging/ath6kl/include/common/bmi_msg.h b/drivers/staging/ath6kl/include/common/bmi_msg.h
index 171bf378baa0..e76624c5915c 100644
--- a/drivers/staging/ath6kl/include/common/bmi_msg.h
+++ b/drivers/staging/ath6kl/include/common/bmi_msg.h
@@ -65,7 +65,7 @@
/*
* Semantics: Host is done using BMI
* Request format:
- * A_UINT32 command (BMI_DONE)
+ * u32 command (BMI_DONE)
* Response format: none
*/
@@ -73,9 +73,9 @@
/*
* Semantics: Host reads AR6K memory
* Request format:
* A_UINT32 command (BMI_READ_MEMORY)
* A_UINT32 address
* A_UINT32 length, at most BMI_DATASZ_MAX
* Response format:
* u8 data[length]
*/
@@ -84,9 +84,9 @@
/*
* Semantics: Host writes AR6K memory
* Request format:
* A_UINT32 command (BMI_WRITE_MEMORY)
* A_UINT32 address
* A_UINT32 length, at most BMI_DATASZ_MAX
* u8 data[length]
* Response format: none
*/
@@ -95,19 +95,19 @@
/*
* Semantics: Causes AR6K to execute code
* Request format:
* A_UINT32 command (BMI_EXECUTE)
* A_UINT32 address
* A_UINT32 parameter
* Response format:
- * A_UINT32 return value
+ * u32 return value
*/
#define BMI_SET_APP_START 5
/*
* Semantics: Set Target application starting address
* Request format:
- * A_UINT32 command (BMI_SET_APP_START)
- * A_UINT32 address
+ * u32 command (BMI_SET_APP_START)
+ * u32 address
* Response format: none
*/
@@ -115,19 +115,19 @@
/*
* Semantics: Read a 32-bit Target SOC register.
* Request format:
- * A_UINT32 command (BMI_READ_REGISTER)
- * A_UINT32 address
+ * u32 command (BMI_READ_REGISTER)
+ * u32 address
* Response format:
- * A_UINT32 value
+ * u32 value
*/
#define BMI_WRITE_SOC_REGISTER 7
/*
* Semantics: Write a 32-bit Target SOC register.
* Request format:
* A_UINT32 command (BMI_WRITE_REGISTER)
* A_UINT32 address
* A_UINT32 value
*
* Response format: none
*/
@@ -137,18 +137,18 @@
/*
* Semantics: Fetch the 4-byte Target information
* Request format:
- * A_UINT32 command (BMI_GET_TARGET_ID/INFO)
+ * u32 command (BMI_GET_TARGET_ID/INFO)
* Response format1 (old firmware):
- * A_UINT32 TargetVersionID
+ * u32 TargetVersionID
* Response format2 (newer firmware):
- * A_UINT32 TARGET_VERSION_SENTINAL
+ * u32 TARGET_VERSION_SENTINAL
* struct bmi_target_info;
*/
PREPACK struct bmi_target_info {
- A_UINT32 target_info_byte_count; /* size of this structure */
- A_UINT32 target_ver; /* Target Version ID */
- A_UINT32 target_type; /* Target type */
+ u32 target_info_byte_count; /* size of this structure */
+ u32 target_ver; /* Target Version ID */
+ u32 target_type; /* Target type */
} POSTPACK;
#define TARGET_VERSION_SENTINAL 0xffffffff
#define TARGET_TYPE_AR6001 1
@@ -160,14 +160,14 @@ PREPACK struct bmi_target_info {
/*
* Semantics: Install a ROM Patch.
* Request format:
* A_UINT32 command (BMI_ROMPATCH_INSTALL)
* A_UINT32 Target ROM Address
* A_UINT32 Target RAM Address or Value (depending on Target Type)
* A_UINT32 Size, in bytes
* A_UINT32 Activate? 1-->activate;
* 0-->install but do not activate
* Response format:
- * A_UINT32 PatchID
+ * u32 PatchID
*/
#define BMI_ROMPATCH_UNINSTALL 10
@@ -175,8 +175,8 @@ PREPACK struct bmi_target_info {
* Semantics: Uninstall a previously-installed ROM Patch,
* automatically deactivating, if necessary.
* Request format:
- * A_UINT32 command (BMI_ROMPATCH_UNINSTALL)
- * A_UINT32 PatchID
+ * u32 command (BMI_ROMPATCH_UNINSTALL)
+ * u32 PatchID
*
* Response format: none
*/
@@ -185,9 +185,9 @@ PREPACK struct bmi_target_info {
/*
* Semantics: Activate a list of previously-installed ROM Patches.
* Request format:
- * A_UINT32 command (BMI_ROMPATCH_ACTIVATE)
- * A_UINT32 rompatch_count
- * A_UINT32 PatchID[rompatch_count]
+ * u32 command (BMI_ROMPATCH_ACTIVATE)
+ * u32 rompatch_count
+ * u32 PatchID[rompatch_count]
*
* Response format: none
*/
@@ -196,9 +196,9 @@ PREPACK struct bmi_target_info {
/*
* Semantics: Deactivate a list of active ROM Patches.
* Request format:
- * A_UINT32 command (BMI_ROMPATCH_DEACTIVATE)
- * A_UINT32 rompatch_count
- * A_UINT32 PatchID[rompatch_count]
+ * u32 command (BMI_ROMPATCH_DEACTIVATE)
+ * u32 rompatch_count
+ * u32 PatchID[rompatch_count]
*
* Response format: none
*/
@@ -213,8 +213,8 @@ PREPACK struct bmi_target_info {
* output from the compressed input stream. This BMI
* command should be followed by a series of 1 or more
* BMI_LZ_DATA commands.
- * A_UINT32 command (BMI_LZ_STREAM_START)
- * A_UINT32 address
+ * u32 command (BMI_LZ_STREAM_START)
+ * u32 address
* Note: Not supported on all versions of ROM firmware.
*/
@@ -226,8 +226,8 @@ PREPACK struct bmi_target_info {
* of BMI_LZ_DATA commands are considered part of a single
* input stream until another BMI_LZ_STREAM_START is issued.
* Request format:
* A_UINT32 command (BMI_LZ_DATA)
* A_UINT32 length (of compressed data),
* at most BMI_DATASZ_MAX
* u8 CompressedData[length]
* Response format: none
@@ -73,9 +73,9 @@
* Semantics: Host reads AR6K memory
* Request format:
- * A_UINT32 command (BMI_READ_MEMORY)
- * A_UINT32 address
- * A_UINT32 length, at most BMI_DATASZ_MAX
+ * u32 command (BMI_READ_MEMORY)
+ * u32 address
+ * u32 length, at most BMI_DATASZ_MAX
* Response format:
* u8 data[length]
@@ -84,9 +84,9 @@
* Semantics: Host writes AR6K memory
* Request format:
- * A_UINT32 command (BMI_WRITE_MEMORY)
- * A_UINT32 address
- * A_UINT32 length, at most BMI_DATASZ_MAX
+ * u32 command (BMI_WRITE_MEMORY)
+ * u32 address
+ * u32 length, at most BMI_DATASZ_MAX
* u8 data[length]
* Response format: none
@@ -95,19 +95,19 @@
* Semantics: Causes AR6K to execute code
* Request format:
- * A_UINT32 command (BMI_EXECUTE)
- * A_UINT32 address
- * A_UINT32 parameter
+ * u32 command (BMI_EXECUTE)
+ * u32 address
+ * u32 parameter
* Response format:
@@ -115,19 +115,19 @@
* Semantics: Write a 32-bit Target SOC register.
* Request format:
- * A_UINT32 command (BMI_WRITE_REGISTER)
- * A_UINT32 address
- * A_UINT32 value
+ * u32 command (BMI_WRITE_REGISTER)
+ * u32 address
+ * u32 value
*
* Response format: none
@@ -160,14 +160,14 @@ PREPACK struct bmi_target_info {
* Semantics: Install a ROM Patch.
* Request format:
- * A_UINT32 command (BMI_ROMPATCH_INSTALL)
- * A_UINT32 Target ROM Address
- * A_UINT32 Target RAM Address or Value (depending on Target Type)
- * A_UINT32 Size, in bytes
- * A_UINT32 Activate? 1-->activate;
+ * u32 command (BMI_ROMPATCH_INSTALL)
+ * u32 Target ROM Address
+ * u32 Target RAM Address or Value (depending on Target Type)
+ * u32 Size, in bytes
+ * u32 Activate? 1-->activate;
* 0-->install but do not activate
* Response format:
@@ -226,8 +226,8 @@ PREPACK struct bmi_target_info {
* input stream until another BMI_LZ_STREAM_START is issued.
* Request format:
- * A_UINT32 command (BMI_LZ_DATA)
- * A_UINT32 length (of compressed data),
+ * u32 command (BMI_LZ_DATA)
+ * u32 length (of compressed data),
* at most BMI_DATASZ_MAX
* u8 CompressedData[length]
diff --git a/drivers/staging/ath6kl/include/common/targaddrs.h b/drivers/staging/ath6kl/include/common/targaddrs.h
index e8cf70354d21..794ae2182a77 100644
--- a/drivers/staging/ath6kl/include/common/targaddrs.h
+++ b/drivers/staging/ath6kl/include/common/targaddrs.h
@@ -83,13 +83,13 @@ PREPACK struct host_interest_s {
* Pointer to application-defined area, if any.
* Set by Target application during startup.
*/
- A_UINT32 hi_app_host_interest; /* 0x00 */
+ u32 hi_app_host_interest; /* 0x00 */
/* Pointer to register dump area, valid after Target crash. */
- A_UINT32 hi_failure_state; /* 0x04 */
+ u32 hi_failure_state; /* 0x04 */
/* Pointer to debug logging header */
- A_UINT32 hi_dbglog_hdr; /* 0x08 */
+ u32 hi_dbglog_hdr; /* 0x08 */
/* Indicates whether or not flash is present on Target.
* NB: flash_is_present indicator is here not just
@@ -99,36 +99,36 @@ PREPACK struct host_interest_s {
* so that it doesn't get reinitialized with the rest
* of data.
*/
- A_UINT32 hi_flash_is_present; /* 0x0c */
+ u32 hi_flash_is_present; /* 0x0c */
/*
* General-purpose flag bits, similar to AR6000_OPTION_* flags.
* Can be used by application rather than by OS.
*/
- A_UINT32 hi_option_flag; /* 0x10 */
+ u32 hi_option_flag; /* 0x10 */
/*
* Boolean that determines whether or not to
* display messages on the serial port.
*/
- A_UINT32 hi_serial_enable; /* 0x14 */
+ u32 hi_serial_enable; /* 0x14 */
/* Start address of Flash DataSet index, if any */
- A_UINT32 hi_dset_list_head; /* 0x18 */
+ u32 hi_dset_list_head; /* 0x18 */
/* Override Target application start address */
- A_UINT32 hi_app_start; /* 0x1c */
+ u32 hi_app_start; /* 0x1c */
/* Clock and voltage tuning */
- A_UINT32 hi_skip_clock_init; /* 0x20 */
- A_UINT32 hi_core_clock_setting; /* 0x24 */
- A_UINT32 hi_cpu_clock_setting; /* 0x28 */
- A_UINT32 hi_system_sleep_setting; /* 0x2c */
- A_UINT32 hi_xtal_control_setting; /* 0x30 */
- A_UINT32 hi_pll_ctrl_setting_24ghz; /* 0x34 */
- A_UINT32 hi_pll_ctrl_setting_5ghz; /* 0x38 */
- A_UINT32 hi_ref_voltage_trim_setting; /* 0x3c */
- A_UINT32 hi_clock_info; /* 0x40 */
+ u32 hi_skip_clock_init; /* 0x20 */
+ u32 hi_core_clock_setting; /* 0x24 */
+ u32 hi_cpu_clock_setting; /* 0x28 */
+ u32 hi_system_sleep_setting; /* 0x2c */
+ u32 hi_xtal_control_setting; /* 0x30 */
+ u32 hi_pll_ctrl_setting_24ghz; /* 0x34 */
+ u32 hi_pll_ctrl_setting_5ghz; /* 0x38 */
+ u32 hi_ref_voltage_trim_setting; /* 0x3c */
+ u32 hi_clock_info; /* 0x40 */
/*
* Flash configuration overrides, used only
@@ -136,49 +136,49 @@ PREPACK struct host_interest_s {
* (When using flash, modify the global variables
* with equivalent names.)
*/
- A_UINT32 hi_bank0_addr_value; /* 0x44 */
- A_UINT32 hi_bank0_read_value; /* 0x48 */
- A_UINT32 hi_bank0_write_value; /* 0x4c */
- A_UINT32 hi_bank0_config_value; /* 0x50 */
+ u32 hi_bank0_addr_value; /* 0x44 */
+ u32 hi_bank0_read_value; /* 0x48 */
+ u32 hi_bank0_write_value; /* 0x4c */
+ u32 hi_bank0_config_value; /* 0x50 */
/* Pointer to Board Data */
- A_UINT32 hi_board_data; /* 0x54 */
- A_UINT32 hi_board_data_initialized; /* 0x58 */
+ u32 hi_board_data; /* 0x54 */
+ u32 hi_board_data_initialized; /* 0x58 */
- A_UINT32 hi_dset_RAM_index_table; /* 0x5c */
+ u32 hi_dset_RAM_index_table; /* 0x5c */
- A_UINT32 hi_desired_baud_rate; /* 0x60 */
- A_UINT32 hi_dbglog_config; /* 0x64 */
- A_UINT32 hi_end_RAM_reserve_sz; /* 0x68 */
- A_UINT32 hi_mbox_io_block_sz; /* 0x6c */
+ u32 hi_desired_baud_rate; /* 0x60 */
+ u32 hi_dbglog_config; /* 0x64 */
+ u32 hi_end_RAM_reserve_sz; /* 0x68 */
+ u32 hi_mbox_io_block_sz; /* 0x6c */
- A_UINT32 hi_num_bpatch_streams; /* 0x70 -- unused */
- A_UINT32 hi_mbox_isr_yield_limit; /* 0x74 */
+ u32 hi_num_bpatch_streams; /* 0x70 -- unused */
+ u32 hi_mbox_isr_yield_limit; /* 0x74 */
- A_UINT32 hi_refclk_hz; /* 0x78 */
- A_UINT32 hi_ext_clk_detected; /* 0x7c */
- A_UINT32 hi_dbg_uart_txpin; /* 0x80 */
- A_UINT32 hi_dbg_uart_rxpin; /* 0x84 */
- A_UINT32 hi_hci_uart_baud; /* 0x88 */
- A_UINT32 hi_hci_uart_pin_assignments; /* 0x8C */
+ u32 hi_refclk_hz; /* 0x78 */
+ u32 hi_ext_clk_detected; /* 0x7c */
+ u32 hi_dbg_uart_txpin; /* 0x80 */
+ u32 hi_dbg_uart_rxpin; /* 0x84 */
+ u32 hi_hci_uart_baud; /* 0x88 */
+ u32 hi_hci_uart_pin_assignments; /* 0x8C */
/* NOTE: byte [0] = tx pin, [1] = rx pin, [2] = rts pin, [3] = cts pin */
- A_UINT32 hi_hci_uart_baud_scale_val; /* 0x90 */
- A_UINT32 hi_hci_uart_baud_step_val; /* 0x94 */
+ u32 hi_hci_uart_baud_scale_val; /* 0x90 */
+ u32 hi_hci_uart_baud_step_val; /* 0x94 */
- A_UINT32 hi_allocram_start; /* 0x98 */
- A_UINT32 hi_allocram_sz; /* 0x9c */
- A_UINT32 hi_hci_bridge_flags; /* 0xa0 */
- A_UINT32 hi_hci_uart_support_pins; /* 0xa4 */
+ u32 hi_allocram_start; /* 0x98 */
+ u32 hi_allocram_sz; /* 0x9c */
+ u32 hi_hci_bridge_flags; /* 0xa0 */
+ u32 hi_hci_uart_support_pins; /* 0xa4 */
/* NOTE: byte [0] = RESET pin (bit 7 is polarity), bytes[1]..bytes[3] are for future use */
- A_UINT32 hi_hci_uart_pwr_mgmt_params; /* 0xa8 */
+ u32 hi_hci_uart_pwr_mgmt_params; /* 0xa8 */
/* 0xa8 - [0]: 1 = enable, 0 = disable
* [1]: 0 = UART FC active low, 1 = UART FC active high
* 0xa9 - [7:0]: wakeup timeout in ms
* 0xaa, 0xab - [15:0]: idle timeout in ms
*/
/* Pointer to extended board Data */
- A_UINT32 hi_board_ext_data; /* 0xac */
- A_UINT32 hi_board_ext_data_initialized; /* 0xb0 */
+ u32 hi_board_ext_data; /* 0xac */
+ u32 hi_board_ext_data_initialized; /* 0xb0 */
} POSTPACK;
/* Bits defined in hi_option_flag */
@@ -207,10 +207,10 @@ PREPACK struct host_interest_s {
* Example: target_addr = AR6002_HOST_INTEREST_ITEM_ADDRESS(hi_board_data);
*/
#define AR6002_HOST_INTEREST_ITEM_ADDRESS(item) \
- (A_UINT32)((unsigned long)&((((struct host_interest_s *)(AR6002_HOST_INTEREST_ADDRESS))->item)))
+ (u32)((unsigned long)&((((struct host_interest_s *)(AR6002_HOST_INTEREST_ADDRESS))->item)))
#define AR6003_HOST_INTEREST_ITEM_ADDRESS(item) \
- (A_UINT32)((unsigned long)&((((struct host_interest_s *)(AR6003_HOST_INTEREST_ADDRESS))->item)))
+ (u32)((unsigned long)&((((struct host_interest_s *)(AR6003_HOST_INTEREST_ADDRESS))->item)))
#define HOST_INTEREST_DBGLOG_IS_ENABLED() \
(!(HOST_INTEREST->hi_option_flag & HI_OPTION_DISABLE_DBGLOG))
@@ -233,7 +233,7 @@ PREPACK struct host_interest_s {
#define AR6003_BOARD_EXT_DATA_ADDRESS 0x57E600
/* # of A_UINT32 entries in targregs, used by DIAG_FETCH_TARG_REGS */
#define AR6003_FETCH_TARG_REGS_COUNT 64
#endif /* !__ASSEMBLER__ */
@@ -233,7 +233,7 @@ PREPACK struct host_interest_s {
#define AR6003_BOARD_EXT_DATA_ADDRESS 0x57E600
-/* # of A_UINT32 entries in targregs, used by DIAG_FETCH_TARG_REGS */
+/* # of u32 entries in targregs, used by DIAG_FETCH_TARG_REGS */
#define AR6003_FETCH_TARG_REGS_COUNT 64
#endif /* !__ASSEMBLER__ */